diff --git a/src/backend/commands/async.c b/src/backend/commands/async.c
index 0c9d20ebfc..68a9db0f20 100644
--- a/src/backend/commands/async.c
+++ b/src/backend/commands/async.c
@@ -819,7 +819,7 @@ pg_listening_channels(PG_FUNCTION_ARGS)
 	if (SRF_IS_FIRSTCALL())
 	{
 		/* create a function context for cross-call persistence */
-		funcctx = SRF_FIRSTCALL_INIT();
+		SRF_FIRSTCALL_INIT();
 	}
 
 	/* stuff done on every call of the function */
diff --git a/src/backend/optimizer/util/plancat.c b/src/backend/optimizer/util/plancat.c
index d82fc5ab8b..d9b80dd53d 100644
--- a/src/backend/optimizer/util/plancat.c
+++ b/src/backend/optimizer/util/plancat.c
@@ -971,11 +971,6 @@ estimate_rel_size(Relation rel, int32 *attr_widths,
 			/* it has storage, ok to call the smgr */
 			curpages = RelationGetNumberOfBlocks(rel);
 
-			/* coerce values in pg_class to more desirable types */
-			relpages = (BlockNumber) rel->rd_rel->relpages;
-			reltuples = (double) rel->rd_rel->reltuples;
-			relallvisible = (BlockNumber) rel->rd_rel->relallvisible;
-
 			/* report estimated # pages */
 			*pages = curpages;
 			/* quick exit if rel is clearly empty */
diff --git a/src/backend/parser/parse_node.c b/src/backend/parser/parse_node.c
index 6e98fe55fc..3ca9db2ec9 100644
--- a/src/backend/parser/parse_node.c
+++ b/src/backend/parser/parse_node.c
@@ -418,9 +418,6 @@ transformContainerSubscripts(ParseState *pstate,
 	 * Ready to build the SubscriptingRef node.
 	 */
 	sbsref = (SubscriptingRef *) makeNode(SubscriptingRef);
-	if (assignFrom != NULL)
-		sbsref->refassgnexpr = (Expr *) assignFrom;
-
 	sbsref->refcontainertype = containerType;
 	sbsref->refelemtype = elementType;
 	sbsref->reftypmod = containerTypMod;

diff --git a/src/backend/utils/adt/formatting.c b/src/backend/utils/adt/formatting.c
index 95f7d0538e..b266e8639e 100644
--- a/src/backend/utils/adt/formatting.c
+++ b/src/backend/utils/adt/formatting.c
@@ -6451,7 +6451,7 @@ float4_to_char(PG_FUNCTION_ARGS)
 		}
 		else
 		{
-			numstr = orgnum = psprintf("%+.*e", Num.post, value);
+			orgnum = psprintf("%+.*e", Num.post, value);
 
 			/*
 			 * Swap a leading positive sign for a space.
@@ -6555,7 +6555,7 @@ float8_to_char(PG_FUNCTION_ARGS)
 		}
 		else
 		{
-			numstr = orgnum = (char *) psprintf("%+.*e", Num.post, value);
+			orgnum = (char *) psprintf("%+.*e", Num.post, value);
 
 			/*
 			 * Swap a leading positive sign for a space.
 
diff --git a/src/backend/utils/adt/jsonfuncs.c b/src/backend/utils/adt/jsonfuncs.c
index 4b5007e0d6..44fe385f74 100644
--- a/src/backend/utils/adt/jsonfuncs.c
+++ b/src/backend/utils/adt/jsonfuncs.c
@@ -5344,7 +5344,6 @@ transform_json_string_values(text *json, void *action_state,
 	sem->object_end = transform_string_values_object_end;
 	sem->array_start = transform_string_values_array_start;
 	sem->array_end = transform_string_values_array_end;
-	sem->scalar = transform_string_values_scalar;
 	sem->array_element_start = transform_string_values_array_element_start;
 	sem->object_field_start = transform_string_values_object_field_start;
 
diff --git a/src/backend/utils/adt/network.c b/src/backend/utils/adt/network.c
index 0ab54316f8..e8d7f3ee4c 100644
--- a/src/backend/utils/adt/network.c
+++ b/src/backend/utils/adt/network.c
@@ -217,7 +217,7 @@ network_recv(StringInfo buf, bool is_cidr)
 				 errmsg("invalid bits in external \"%s\" value",
 						is_cidr ? "cidr" : "inet")));
 	ip_bits(addr) = bits;
-	i = pq_getmsgbyte(buf);		/* ignore is_cidr */
+	pq_getmsgbyte(buf);		/* ignore is_cidr */
 	nb = pq_getmsgbyte(buf);
 	if (nb != ip_addrsize(addr))
 		ereport(ERROR,
 
diff --git a/src/backend/utils/sort/logtape.c b/src/backend/utils/sort/logtape.c
index 7ae160e196..d3518c1bc8 100644
--- a/src/backend/utils/sort/logtape.c
+++ b/src/backend/utils/sort/logtape.c
@@ -962,7 +962,6 @@ LogicalTapeFreeze(LogicalTapeSet *lts, int tapenum, TapeShare *share)
 
 		TapeBlockSetNBytes(lt->buffer, lt->nbytes);
 		ltsWriteBlock(lts, lt->curBlockNumber, (void *) lt->buffer);
-		lt->writing = false;
 	}
 	lt->writing = false;
 	lt->frozen = true;
